# coding: utf-8

"""
    Kestra EE

    All API operations, except for Superadmin-only endpoints, require a tenant identifier in the HTTP path.<br/> Endpoints designated as Superadmin-only are not tenant-scoped.

    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501
# Custom imports
import requests
import sseclient
import json
from typing import Generator


import warnings
from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Any, Dict, List, Optional, Tuple, Union
from typing_extensions import Annotated

from pydantic import Field, StrictBool, StrictInt, StrictStr
from typing import Any, Dict, List, Optional
from typing_extensions import Annotated
from kestrapy.models.api_autocomplete import ApiAutocomplete
from kestrapy.models.api_secret_list_response_api_secret_meta import ApiSecretListResponseApiSecretMeta
from kestrapy.models.api_secret_meta_ee import ApiSecretMetaEE
from kestrapy.models.api_secret_value import ApiSecretValue
from kestrapy.models.namespace import Namespace
from kestrapy.models.paged_results_namespace import PagedResultsNamespace
from kestrapy.models.plugin_default import PluginDefault
from kestrapy.models.query_filter import QueryFilter

from kestrapy.api_client import ApiClient, RequestSerialized
from kestrapy.api_response import ApiResponse
from kestrapy.rest import RESTResponseType


class NamespacesApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client

    @validate_call
    def autocomplete_namespaces(
        self,
        tenant: StrictStr,
        api_autocomplete: ApiAutocomplete,
        _request_timeout: Union[
        None,
        Annotated[StrictFloat, Field(gt=0)],
        Tuple[
        Annotated[StrictFloat, Field(gt=0)],
        Annotated[StrictFloat, Field(gt=0)]
        ]
        ] = None
    ) -> List[str]:
        """List namespaces for autocomplete

        Returns a list of namespaces for use in autocomplete fields, optionally allowing to filter by query and ids. Used especially for binding creation.

        :param tenant: (required)
        :type tenant: str
                :param api_autocomplete: (required)
        :type api_autocomplete: ApiAutocomplete
        ,
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        """ # noqa: E501

        _param = self._autocomplete_namespaces_serialize(
            tenant=tenant,
            api_autocomplete=api_autocomplete,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "List[str]",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def autocomplete_namespaces_with_http_info(
        self,
        tenant: StrictStr,
        api_autocomplete: ApiAutocomplete,
        _request_timeout: Union[
        None,
        Annotated[StrictFloat, Field(gt=0)],
        Tuple[
        Annotated[StrictFloat, Field(gt=0)],
        Annotated[StrictFloat, Field(gt=0)]
        ]
        ] = None
    ) -> ApiResponse[List[str]]:
        """List namespaces for autocomplete

        Returns a list of namespaces for use in autocomplete fields, optionally allowing to filter by query and ids. Used especially for binding creation.

        :param tenant: (required)
        :type tenant: str
                :param api_autocomplete: (required)
        :type api_autocomplete: ApiAutocomplete
        ,
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        """ # noqa: E501

        _param = self._autocomplete_namespaces_serialize(
            tenant=tenant,
            api_autocomplete=api_autocomplete,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "List[str]",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    def _autocomplete_namespaces_serialize(
        self,
        tenant,
        api_autocomplete,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if tenant is not None:
            _path_params['tenant'] = tenant
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if api_autocomplete is not None:
            _body_params = api_autocomplete



        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`

        _default_content_type = (
            self.api_client.select_header_content_type(
                [
                    'application/json'
                ]
            )
        )
        if _default_content_type is not None:
            _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'basicAuth', 
            'bearerAuth'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/api/v1/{tenant}/namespaces/autocomplete',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats
        )





    @validate_call
    def create_namespace(
        self,
        tenant: StrictStr,
        namespace: Annotated[Namespace, Field(description="The namespace")],
        _request_timeout: Union[
        None,
        Annotated[StrictFloat, Field(gt=0)],
        Tuple[
        Annotated[StrictFloat, Field(gt=0)],
        Annotated[StrictFloat, Field(gt=0)]
        ]
        ] = None
    ) -> Namespace:
        """Create a namespace


        :param tenant: (required)
        :type tenant: str
                :param namespace: The namespace (required)
        :type namespace: Namespace
        ,
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        """ # noqa: E501

        _param = self._create_namespace_serialize(
            tenant=tenant,
            namespace=namespace,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "Namespace",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def create_namespace_with_http_info(
        self,
        tenant: StrictStr,
        namespace: Annotated[Namespace, Field(description="The namespace")],
        _request_timeout: Union[
        None,
        Annotated[StrictFloat, Field(gt=0)],
        Tuple[
        Annotated[StrictFloat, Field(gt=0)],
        Annotated[StrictFloat, Field(gt=0)]
        ]
        ] = None
    ) -> ApiResponse[Namespace]:
        """Create a namespace


        :param tenant: (required)
        :type tenant: str
                :param namespace: The namespace (required)
        :type namespace: Namespace
        ,
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        """ # noqa: E501

        _param = self._create_namespace_serialize(
            tenant=tenant,
            namespace=namespace,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "Namespace",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    def _create_namespace_serialize(
        self,
        tenant,
        namespace,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if tenant is not None:
            _path_params['tenant'] = tenant
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if namespace is not None:
            _body_params = namespace



        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`

        _default_content_type = (
            self.api_client.select_header_content_type(
                [
                    'application/json'
                ]
            )
        )
        if _default_content_type is not None:
            _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'basicAuth', 
            'bearerAuth'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/api/v1/{tenant}/namespaces',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats
        )





    @validate_call
    def delete_namespace(
        self,
        id: Annotated[StrictStr, Field(description="The namespace id")],
        tenant: StrictStr,
        _request_timeout: Union[
        None,
        Annotated[StrictFloat, Field(gt=0)],
        Tuple[
        Annotated[StrictFloat, Field(gt=0)],
        Annotated[StrictFloat, Field(gt=0)]
        ]
        ] = None
    ) -> None:
        """Delete a namespace


        :param id: The namespace id (required)
        :type id: str
                :param tenant: (required)
        :type tenant: str
        ,
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        """ # noqa: E501

        _param = self._delete_namespace_serialize(
            id=id,
            tenant=tenant,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '204': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def delete_namespace_with_http_info(
        self,
        id: Annotated[StrictStr, Field(description="The namespace id")],
        tenant: StrictStr,
        _request_timeout: Union[
        None,
        Annotated[StrictFloat, Field(gt=0)],
        Tuple[
        Annotated[StrictFloat, Field(gt=0)],
        Annotated[StrictFloat, Field(gt=0)]
        ]
        ] = None
    ) -> ApiResponse[None]:
        """Delete a namespace


        :param id: The namespace id (required)
        :type id: str
                :param tenant: (required)
        :type tenant: str
        ,
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        """ # noqa: E501

        _param = self._delete_namespace_serialize(
            id=id,
            tenant=tenant,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '204': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    def _delete_namespace_serialize(
        self,
        id,
        tenant,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if id is not None:
            _path_params['id'] = id
        if tenant is not None:
            _path_params['tenant'] = tenant
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter





        # authentication setting
        _auth_settings: List[str] = [
            'basicAuth', 
            'bearerAuth'
        ]

        return self.api_client.param_serialize(
            method='DELETE',
            resource_path='/api/v1/{tenant}/namespaces/{id}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats
        )





    @validate_call
    def delete_secret(
        self,
        namespace: Annotated[StrictStr, Field(description="The namespace id")],
        key: Annotated[StrictStr, Field(description="The secret key")],
        tenant: StrictStr,
        _request_timeout: Union[
        None,
        Annotated[StrictFloat, Field(gt=0)],
        Tuple[
        Annotated[StrictFloat, Field(gt=0)],
        Annotated[StrictFloat, Field(gt=0)]
        ]
        ] = None
    ) -> None:
        """Delete a secret for a namespace


        :param namespace: The namespace id (required)
        :type namespace: str
                :param key: The secret key (required)
        :type key: str
                :param tenant: (required)
        :type tenant: str
        ,
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        """ # noqa: E501

        _param = self._delete_secret_serialize(
            namespace=namespace,
            key=key,
            tenant=tenant,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def delete_secret_with_http_info(
        self,
        namespace: Annotated[StrictStr, Field(description="The namespace id")],
        key: Annotated[StrictStr, Field(description="The secret key")],
        tenant: StrictStr,
        _request_timeout: Union[
        None,
        Annotated[StrictFloat, Field(gt=0)],
        Tuple[
        Annotated[StrictFloat, Field(gt=0)],
        Annotated[StrictFloat, Field(gt=0)]
        ]
        ] = None
    ) -> ApiResponse[None]:
        """Delete a secret for a namespace


        :param namespace: The namespace id (required)
        :type namespace: str
                :param key: The secret key (required)
        :type key: str
                :param tenant: (required)
        :type tenant: str
        ,
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        """ # noqa: E501

        _param = self._delete_secret_serialize(
            namespace=namespace,
            key=key,
            tenant=tenant,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    def _delete_secret_serialize(
        self,
        namespace,
        key,
        tenant,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if namespace is not None:
            _path_params['namespace'] = namespace
        if key is not None:
            _path_params['key'] = key
        if tenant is not None:
            _path_params['tenant'] = tenant
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter





        # authentication setting
        _auth_settings: List[str] = [
            'basicAuth', 
            'bearerAuth'
        ]

        return self.api_client.param_serialize(
            method='DELETE',
            resource_path='/api/v1/{tenant}/namespaces/{namespace}/secrets/{key}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats
        )





    @validate_call
    def inherited_plugin_defaults(
        self,
        id: Annotated[StrictStr, Field(description="The namespace id")],
        tenant: StrictStr,
        _request_timeout: Union[
        None,
        Annotated[StrictFloat, Field(gt=0)],
        Tuple[
        Annotated[StrictFloat, Field(gt=0)],
        Annotated[StrictFloat, Field(gt=0)]
        ]
        ] = None
    ) -> List[PluginDefault]:
        """List inherited plugin defaults


        :param id: The namespace id (required)
        :type id: str
                :param tenant: (required)
        :type tenant: str
        ,
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        """ # noqa: E501

        _param = self._inherited_plugin_defaults_serialize(
            id=id,
            tenant=tenant,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "List[PluginDefault]",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def inherited_plugin_defaults_with_http_info(
        self,
        id: Annotated[StrictStr, Field(description="The namespace id")],
        tenant: StrictStr,
        _request_timeout: Union[
        None,
        Annotated[StrictFloat, Field(gt=0)],
        Tuple[
        Annotated[StrictFloat, Field(gt=0)],
        Annotated[StrictFloat, Field(gt=0)]
        ]
        ] = None
    ) -> ApiResponse[List[PluginDefault]]:
        """List inherited plugin defaults


        :param id: The namespace id (required)
        :type id: str
                :param tenant: (required)
        :type tenant: str
        ,
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        """ # noqa: E501

        _param = self._inherited_plugin_defaults_serialize(
            id=id,
            tenant=tenant,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "List[PluginDefault]",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    def _inherited_plugin_defaults_serialize(
        self,
        id,
        tenant,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if id is not None:
            _path_params['id'] = id
        if tenant is not None:
            _path_params['tenant'] = tenant
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter



        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'basicAuth', 
            'bearerAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/v1/{tenant}/namespaces/{id}/inherited-plugindefaults',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats
        )





    @validate_call
    def inherited_secrets(
        self,
        namespace: Annotated[StrictStr, Field(description="The namespace id")],
        tenant: StrictStr,
        _request_timeout: Union[
        None,
        Annotated[StrictFloat, Field(gt=0)],
        Tuple[
        Annotated[StrictFloat, Field(gt=0)],
        Annotated[StrictFloat, Field(gt=0)]
        ]
        ] = None
    ) -> Dict[str, List[str]]:
        """List inherited secrets


        :param namespace: The namespace id (required)
        :type namespace: str
                :param tenant: (required)
        :type tenant: str
        ,
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        """ # noqa: E501

        _param = self._inherited_secrets_serialize(
            namespace=namespace,
            tenant=tenant,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "Dict[str, List[str]]",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def inherited_secrets_with_http_info(
        self,
        namespace: Annotated[StrictStr, Field(description="The namespace id")],
        tenant: StrictStr,
        _request_timeout: Union[
        None,
        Annotated[StrictFloat, Field(gt=0)],
        Tuple[
        Annotated[StrictFloat, Field(gt=0)],
        Annotated[StrictFloat, Field(gt=0)]
        ]
        ] = None
    ) -> ApiResponse[Dict[str, List[str]]]:
        """List inherited secrets


        :param namespace: The namespace id (required)
        :type namespace: str
                :param tenant: (required)
        :type tenant: str
        ,
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        """ # noqa: E501

        _param = self._inherited_secrets_serialize(
            namespace=namespace,
            tenant=tenant,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "Dict[str, List[str]]",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    def _inherited_secrets_serialize(
        self,
        namespace,
        tenant,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if namespace is not None:
            _path_params['namespace'] = namespace
        if tenant is not None:
            _path_params['tenant'] = tenant
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter



        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'basicAuth', 
            'bearerAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/v1/{tenant}/namespaces/{namespace}/inherited-secrets',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats
        )





    @validate_call
    def inherited_variables(
        self,
        id: Annotated[StrictStr, Field(description="The namespace id")],
        tenant: StrictStr,
        _request_timeout: Union[
        None,
        Annotated[StrictFloat, Field(gt=0)],
        Tuple[
        Annotated[StrictFloat, Field(gt=0)],
        Annotated[StrictFloat, Field(gt=0)]
        ]
        ] = None
    ) -> Dict[str, object]:
        """List inherited variables


        :param id: The namespace id (required)
        :type id: str
                :param tenant: (required)
        :type tenant: str
        ,
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        """ # noqa: E501

        _param = self._inherited_variables_serialize(
            id=id,
            tenant=tenant,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "Dict[str, object]",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def inherited_variables_with_http_info(
        self,
        id: Annotated[StrictStr, Field(description="The namespace id")],
        tenant: StrictStr,
        _request_timeout: Union[
        None,
        Annotated[StrictFloat, Field(gt=0)],
        Tuple[
        Annotated[StrictFloat, Field(gt=0)],
        Annotated[StrictFloat, Field(gt=0)]
        ]
        ] = None
    ) -> ApiResponse[Dict[str, object]]:
        """List inherited variables


        :param id: The namespace id (required)
        :type id: str
                :param tenant: (required)
        :type tenant: str
        ,
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        """ # noqa: E501

        _param = self._inherited_variables_serialize(
            id=id,
            tenant=tenant,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "Dict[str, object]",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    def _inherited_variables_serialize(
        self,
        id,
        tenant,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if id is not None:
            _path_params['id'] = id
        if tenant is not None:
            _path_params['tenant'] = tenant
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter



        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'basicAuth', 
            'bearerAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/v1/{tenant}/namespaces/{id}/inherited-variables',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats
        )





    @validate_call
    def list_namespace_secrets(
        self,
        namespace: Annotated[StrictStr, Field(description="The namespace id")],
        page: Annotated[StrictInt, Field(description="The current page")],
        size: Annotated[StrictInt, Field(description="The current page size")],
        filters: Annotated[List[QueryFilter], Field(description="Filters")],
        tenant: StrictStr,
        sort: Annotated[Optional[List[StrictStr]], Field(description="The sort of current page")] = None,
        _request_timeout: Union[
        None,
        Annotated[StrictFloat, Field(gt=0)],
        Tuple[
        Annotated[StrictFloat, Field(gt=0)],
        Annotated[StrictFloat, Field(gt=0)]
        ]
        ] = None
    ) -> ApiSecretListResponseApiSecretMeta:
        """(Deprecated) Get secrets for a namespace


        :param namespace: The namespace id (required)
        :type namespace: str
                :param page: The current page (required)
        :type page: int
                :param size: The current page size (required)
        :type size: int
                :param filters: Filters (required)
        :type filters: List[QueryFilter]
                :param tenant: (required)
        :type tenant: str
                :param sort: The sort of current page
        :type sort: List[str]
        ,
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        """ # noqa: E501
        warnings.warn("GET /api/v1/{tenant}/namespaces/{namespace}/secrets is deprecated.", DeprecationWarning)

        _param = self._list_namespace_secrets_serialize(
            namespace=namespace,
            page=page,
            size=size,
            filters=filters,
            tenant=tenant,
            sort=sort,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ApiSecretListResponseApiSecretMeta",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def list_namespace_secrets_with_http_info(
        self,
        namespace: Annotated[StrictStr, Field(description="The namespace id")],
        page: Annotated[StrictInt, Field(description="The current page")],
        size: Annotated[StrictInt, Field(description="The current page size")],
        filters: Annotated[List[QueryFilter], Field(description="Filters")],
        tenant: StrictStr,
        sort: Annotated[Optional[List[StrictStr]], Field(description="The sort of current page")] = None,
        _request_timeout: Union[
        None,
        Annotated[StrictFloat, Field(gt=0)],
        Tuple[
        Annotated[StrictFloat, Field(gt=0)],
        Annotated[StrictFloat, Field(gt=0)]
        ]
        ] = None
    ) -> ApiResponse[ApiSecretListResponseApiSecretMeta]:
        """(Deprecated) Get secrets for a namespace


        :param namespace: The namespace id (required)
        :type namespace: str
                :param page: The current page (required)
        :type page: int
                :param size: The current page size (required)
        :type size: int
                :param filters: Filters (required)
        :type filters: List[QueryFilter]
                :param tenant: (required)
        :type tenant: str
                :param sort: The sort of current page
        :type sort: List[str]
        ,
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        """ # noqa: E501
        warnings.warn("GET /api/v1/{tenant}/namespaces/{namespace}/secrets is deprecated.", DeprecationWarning)

        _param = self._list_namespace_secrets_serialize(
            namespace=namespace,
            page=page,
            size=size,
            filters=filters,
            tenant=tenant,
            sort=sort,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ApiSecretListResponseApiSecretMeta",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    def _list_namespace_secrets_serialize(
        self,
        namespace,
        page,
        size,
        filters,
        tenant,
        sort,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
            'filters': 'csv',
            'sort': 'csv',
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if namespace is not None:
            _path_params['namespace'] = namespace
        if tenant is not None:
            _path_params['tenant'] = tenant
        # process the query parameters
        if page is not None:
            
            _query_params.append(('page', page))
            
        if size is not None:
            
            _query_params.append(('size', size))
            
        if sort is not None:
            
            _query_params.append(('sort', sort))
            
        if filters is not None:
            
            _query_params.append(('filters', filters))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter



        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'basicAuth', 
            'bearerAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/v1/{tenant}/namespaces/{namespace}/secrets',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats
        )





    @validate_call
    def namespace(
        self,
        id: Annotated[StrictStr, Field(description="The namespace id")],
        tenant: StrictStr,
        _request_timeout: Union[
        None,
        Annotated[StrictFloat, Field(gt=0)],
        Tuple[
        Annotated[StrictFloat, Field(gt=0)],
        Annotated[StrictFloat, Field(gt=0)]
        ]
        ] = None
    ) -> Namespace:
        """Get a namespace


        :param id: The namespace id (required)
        :type id: str
                :param tenant: (required)
        :type tenant: str
        ,
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        """ # noqa: E501

        _param = self._namespace_serialize(
            id=id,
            tenant=tenant,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "Namespace",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def namespace_with_http_info(
        self,
        id: Annotated[StrictStr, Field(description="The namespace id")],
        tenant: StrictStr,
        _request_timeout: Union[
        None,
        Annotated[StrictFloat, Field(gt=0)],
        Tuple[
        Annotated[StrictFloat, Field(gt=0)],
        Annotated[StrictFloat, Field(gt=0)]
        ]
        ] = None
    ) -> ApiResponse[Namespace]:
        """Get a namespace


        :param id: The namespace id (required)
        :type id: str
                :param tenant: (required)
        :type tenant: str
        ,
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        """ # noqa: E501

        _param = self._namespace_serialize(
            id=id,
            tenant=tenant,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "Namespace",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    def _namespace_serialize(
        self,
        id,
        tenant,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if id is not None:
            _path_params['id'] = id
        if tenant is not None:
            _path_params['tenant'] = tenant
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter



        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'basicAuth', 
            'bearerAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/v1/{tenant}/namespaces/{id}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats
        )





    @validate_call
    def patch_secret(
        self,
        namespace: Annotated[StrictStr, Field(description="The namespace id")],
        key: Annotated[StrictStr, Field(description="The secret key")],
        tenant: StrictStr,
        api_secret_meta_ee: ApiSecretMetaEE,
        _request_timeout: Union[
        None,
        Annotated[StrictFloat, Field(gt=0)],
        Tuple[
        Annotated[StrictFloat, Field(gt=0)],
        Annotated[StrictFloat, Field(gt=0)]
        ]
        ] = None
    ) -> List[ApiSecretMetaEE]:
        """Patch a secret metadata for a namespace


        :param namespace: The namespace id (required)
        :type namespace: str
                :param key: The secret key (required)
        :type key: str
                :param tenant: (required)
        :type tenant: str
                :param api_secret_meta_ee: (required)
        :type api_secret_meta_ee: ApiSecretMetaEE
        ,
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        """ # noqa: E501

        _param = self._patch_secret_serialize(
            namespace=namespace,
            key=key,
            tenant=tenant,
            api_secret_meta_ee=api_secret_meta_ee,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "List[ApiSecretMetaEE]",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def patch_secret_with_http_info(
        self,
        namespace: Annotated[StrictStr, Field(description="The namespace id")],
        key: Annotated[StrictStr, Field(description="The secret key")],
        tenant: StrictStr,
        api_secret_meta_ee: ApiSecretMetaEE,
        _request_timeout: Union[
        None,
        Annotated[StrictFloat, Field(gt=0)],
        Tuple[
        Annotated[StrictFloat, Field(gt=0)],
        Annotated[StrictFloat, Field(gt=0)]
        ]
        ] = None
    ) -> ApiResponse[List[ApiSecretMetaEE]]:
        """Patch a secret metadata for a namespace


        :param namespace: The namespace id (required)
        :type namespace: str
                :param key: The secret key (required)
        :type key: str
                :param tenant: (required)
        :type tenant: str
                :param api_secret_meta_ee: (required)
        :type api_secret_meta_ee: ApiSecretMetaEE
        ,
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        """ # noqa: E501

        _param = self._patch_secret_serialize(
            namespace=namespace,
            key=key,
            tenant=tenant,
            api_secret_meta_ee=api_secret_meta_ee,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "List[ApiSecretMetaEE]",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    def _patch_secret_serialize(
        self,
        namespace,
        key,
        tenant,
        api_secret_meta_ee,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if namespace is not None:
            _path_params['namespace'] = namespace
        if key is not None:
            _path_params['key'] = key
        if tenant is not None:
            _path_params['tenant'] = tenant
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if api_secret_meta_ee is not None:
            _body_params = api_secret_meta_ee



        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`

        _default_content_type = (
            self.api_client.select_header_content_type(
                [
                    'application/json'
                ]
            )
        )
        if _default_content_type is not None:
            _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'basicAuth', 
            'bearerAuth'
        ]

        return self.api_client.param_serialize(
            method='PATCH',
            resource_path='/api/v1/{tenant}/namespaces/{namespace}/secrets/{key}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats
        )





    @validate_call
    def put_secrets(
        self,
        namespace: Annotated[StrictStr, Field(description="The namespace id")],
        tenant: StrictStr,
        api_secret_value: ApiSecretValue,
        _request_timeout: Union[
        None,
        Annotated[StrictFloat, Field(gt=0)],
        Tuple[
        Annotated[StrictFloat, Field(gt=0)],
        Annotated[StrictFloat, Field(gt=0)]
        ]
        ] = None
    ) -> List[ApiSecretMetaEE]:
        """Update secrets for a namespace


        :param namespace: The namespace id (required)
        :type namespace: str
                :param tenant: (required)
        :type tenant: str
                :param api_secret_value: (required)
        :type api_secret_value: ApiSecretValue
        ,
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        """ # noqa: E501

        _param = self._put_secrets_serialize(
            namespace=namespace,
            tenant=tenant,
            api_secret_value=api_secret_value,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "List[ApiSecretMetaEE]",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def put_secrets_with_http_info(
        self,
        namespace: Annotated[StrictStr, Field(description="The namespace id")],
        tenant: StrictStr,
        api_secret_value: ApiSecretValue,
        _request_timeout: Union[
        None,
        Annotated[StrictFloat, Field(gt=0)],
        Tuple[
        Annotated[StrictFloat, Field(gt=0)],
        Annotated[StrictFloat, Field(gt=0)]
        ]
        ] = None
    ) -> ApiResponse[List[ApiSecretMetaEE]]:
        """Update secrets for a namespace


        :param namespace: The namespace id (required)
        :type namespace: str
                :param tenant: (required)
        :type tenant: str
                :param api_secret_value: (required)
        :type api_secret_value: ApiSecretValue
        ,
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        """ # noqa: E501

        _param = self._put_secrets_serialize(
            namespace=namespace,
            tenant=tenant,
            api_secret_value=api_secret_value,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "List[ApiSecretMetaEE]",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    def _put_secrets_serialize(
        self,
        namespace,
        tenant,
        api_secret_value,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if namespace is not None:
            _path_params['namespace'] = namespace
        if tenant is not None:
            _path_params['tenant'] = tenant
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if api_secret_value is not None:
            _body_params = api_secret_value



        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`

        _default_content_type = (
            self.api_client.select_header_content_type(
                [
                    'application/json'
                ]
            )
        )
        if _default_content_type is not None:
            _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'basicAuth', 
            'bearerAuth'
        ]

        return self.api_client.param_serialize(
            method='PUT',
            resource_path='/api/v1/{tenant}/namespaces/{namespace}/secrets',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats
        )





    @validate_call
    def search_namespaces(
        self,
        page: Annotated[int, Field(strict=True, ge=1, description="The current page")],
        size: Annotated[int, Field(strict=True, ge=1, description="The current page size")],
        existing: Annotated[StrictBool, Field(description="Return only existing namespace")],
        tenant: StrictStr,
        q: Annotated[Optional[StrictStr], Field(description="A string filter")] = None,
        sort: Annotated[Optional[List[StrictStr]], Field(description="The sort of current page")] = None,
        _request_timeout: Union[
        None,
        Annotated[StrictFloat, Field(gt=0)],
        Tuple[
        Annotated[StrictFloat, Field(gt=0)],
        Annotated[StrictFloat, Field(gt=0)]
        ]
        ] = None
    ) -> PagedResultsNamespace:
        """Search for namespaces


        :param page: The current page (required)
        :type page: int
                :param size: The current page size (required)
        :type size: int
                :param existing: Return only existing namespace (required)
        :type existing: bool
                :param tenant: (required)
        :type tenant: str
                :param q: A string filter
        :type q: str
                :param sort: The sort of current page
        :type sort: List[str]
        ,
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        """ # noqa: E501

        _param = self._search_namespaces_serialize(
            page=page,
            size=size,
            existing=existing,
            tenant=tenant,
            q=q,
            sort=sort,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "PagedResultsNamespace",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def search_namespaces_with_http_info(
        self,
        page: Annotated[int, Field(strict=True, ge=1, description="The current page")],
        size: Annotated[int, Field(strict=True, ge=1, description="The current page size")],
        existing: Annotated[StrictBool, Field(description="Return only existing namespace")],
        tenant: StrictStr,
        q: Annotated[Optional[StrictStr], Field(description="A string filter")] = None,
        sort: Annotated[Optional[List[StrictStr]], Field(description="The sort of current page")] = None,
        _request_timeout: Union[
        None,
        Annotated[StrictFloat, Field(gt=0)],
        Tuple[
        Annotated[StrictFloat, Field(gt=0)],
        Annotated[StrictFloat, Field(gt=0)]
        ]
        ] = None
    ) -> ApiResponse[PagedResultsNamespace]:
        """Search for namespaces


        :param page: The current page (required)
        :type page: int
                :param size: The current page size (required)
        :type size: int
                :param existing: Return only existing namespace (required)
        :type existing: bool
                :param tenant: (required)
        :type tenant: str
                :param q: A string filter
        :type q: str
                :param sort: The sort of current page
        :type sort: List[str]
        ,
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        """ # noqa: E501

        _param = self._search_namespaces_serialize(
            page=page,
            size=size,
            existing=existing,
            tenant=tenant,
            q=q,
            sort=sort,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "PagedResultsNamespace",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    def _search_namespaces_serialize(
        self,
        page,
        size,
        existing,
        tenant,
        q,
        sort,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
            'sort': 'csv',
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if tenant is not None:
            _path_params['tenant'] = tenant
        # process the query parameters
        if q is not None:
            
            _query_params.append(('q', q))
            
        if page is not None:
            
            _query_params.append(('page', page))
            
        if size is not None:
            
            _query_params.append(('size', size))
            
        if sort is not None:
            
            _query_params.append(('sort', sort))
            
        if existing is not None:
            
            _query_params.append(('existing', existing))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter



        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'basicAuth', 
            'bearerAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/v1/{tenant}/namespaces/search',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats
        )





    @validate_call
    def update_namespace(
        self,
        id: Annotated[StrictStr, Field(description="The namespace id")],
        tenant: StrictStr,
        namespace: Annotated[Namespace, Field(description="The namespace")],
        _request_timeout: Union[
        None,
        Annotated[StrictFloat, Field(gt=0)],
        Tuple[
        Annotated[StrictFloat, Field(gt=0)],
        Annotated[StrictFloat, Field(gt=0)]
        ]
        ] = None
    ) -> Namespace:
        """Update a namespace


        :param id: The namespace id (required)
        :type id: str
                :param tenant: (required)
        :type tenant: str
                :param namespace: The namespace (required)
        :type namespace: Namespace
        ,
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        """ # noqa: E501

        _param = self._update_namespace_serialize(
            id=id,
            tenant=tenant,
            namespace=namespace,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "Namespace",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def update_namespace_with_http_info(
        self,
        id: Annotated[StrictStr, Field(description="The namespace id")],
        tenant: StrictStr,
        namespace: Annotated[Namespace, Field(description="The namespace")],
        _request_timeout: Union[
        None,
        Annotated[StrictFloat, Field(gt=0)],
        Tuple[
        Annotated[StrictFloat, Field(gt=0)],
        Annotated[StrictFloat, Field(gt=0)]
        ]
        ] = None
    ) -> ApiResponse[Namespace]:
        """Update a namespace


        :param id: The namespace id (required)
        :type id: str
                :param tenant: (required)
        :type tenant: str
                :param namespace: The namespace (required)
        :type namespace: Namespace
        ,
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        """ # noqa: E501

        _param = self._update_namespace_serialize(
            id=id,
            tenant=tenant,
            namespace=namespace,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "Namespace",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    def _update_namespace_serialize(
        self,
        id,
        tenant,
        namespace,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if id is not None:
            _path_params['id'] = id
        if tenant is not None:
            _path_params['tenant'] = tenant
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if namespace is not None:
            _body_params = namespace



        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`

        _default_content_type = (
            self.api_client.select_header_content_type(
                [
                    'application/json'
                ]
            )
        )
        if _default_content_type is not None:
            _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'basicAuth', 
            'bearerAuth'
        ]

        return self.api_client.param_serialize(
            method='PUT',
            resource_path='/api/v1/{tenant}/namespaces/{id}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats
        )







# coding: utf-8

# flake8: noqa

"""
    Kestra EE

    All API operations, except for Superadmin-only endpoints, require a tenant identifier in the HTTP path.<br/> Endpoints designated as Superadmin-only are not tenant-scoped.

    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


__version__ = "1.0.7"

# Define package exports
__all__ = [
    "ExecutionsApi",
    "FlowsApi",
    "GroupsApi",
    "KVApi",
    "NamespacesApi",
    "RolesApi",
    "ServiceAccountApi",
    "TriggersApi",
    "UsersApi",
    "ApiResponse",
    "Configuration",
    "OpenApiException",
    "ApiTypeError",
    "ApiValueError",
    "ApiKeyError",
    "ApiAttributeError",
    "ApiException",
    "AbstractFlow",
    "AbstractGraph",
    "AbstractGraphBranchType",
    "AbstractMetricEntryObject",
    "AbstractTrigger",
    "AbstractTriggerForExecution",
    "AbstractUser",
    "AbstractUserTenantIdentityProvider",
    "Action",
    "ApiAuth",
    "ApiAutocomplete",
    "ApiGroupSummary",
    "ApiIds",
    "ApiPatchSuperAdminRequest",
    "ApiRoleSummary",
    "ApiSecretListResponseApiSecretMeta",
    "ApiSecretMeta",
    "ApiSecretMetaEE",
    "ApiSecretTag",
    "ApiSecretValue",
    "ApiTenant",
    "ApiTenantSummary",
    "ApiToken",
    "ApiTokenList",
    "ApiUser",
    "AppResponse",
    "AppResponseUILayout",
    "AppsControllerApiApp",
    "AppsControllerApiAppCatalogItem",
    "AppsControllerApiAppSource",
    "AppsControllerApiAppTags",
    "AppsControllerApiBulkImportResponse",
    "AppsControllerApiBulkImportResponseError",
    "AppsControllerApiBulkOperationRequest",
    "Assertion",
    "AssertionResult",
    "AssertionRunError",
    "Asset",
    "AssetIdentifier",
    "AssetTopologyGraph",
    "AssetTopologyGraphEdge",
    "AssetTopologyGraphNode",
    "AssetTopologyGraphNodeNodeType",
    "AssetsControllerApiAsset",
    "AssetsControllerApiAssetUsage",
    "AssetsDeclaration",
    "AssetsInOut",
    "AttributeReference",
    "AuditLog",
    "AuditLogControllerApiAuditLogItem",
    "AuditLogControllerAuditLogDiff",
    "AuditLogControllerAuditLogOption",
    "AuditLogControllerFindRequest",
    "AuditLogDetail",
    "AuthControllerAuth",
    "AuthControllerInvitationUserRequest",
    "AuthControllerResetPasswordRequest",
    "Backfill",
    "Banner",
    "BannerType",
    "BaseAuditLog",
    "BaseResourcePatchRequest",
    "BaseResourceScimResource",
    "BaseResourceSearchRequest",
    "BasicAuthCredentials",
    "Binding",
    "BindingType",
    "Blueprint",
    "BlueprintControllerApiBlueprintItem",
    "BlueprintControllerApiBlueprintItemWithSource",
    "BlueprintControllerApiBlueprintTagItem",
    "BlueprintControllerApiFlowBlueprint",
    "BlueprintControllerFlowBlueprintCreateOrUpdate",
    "BlueprintControllerKind",
    "BlueprintControllerUseBlueprintTemplateRequest",
    "BlueprintControllerUseBlueprintTemplateResponse",
    "BlueprintTemplate",
    "BlueprintWithFlowEntity",
    "Breakpoint",
    "BulkErrorResponse",
    "BulkImportAppsRequest",
    "BulkResponse",
    "Cache",
    "ChartChartOption",
    "ChartFiltersOverrides",
    "Check",
    "CheckBehavior",
    "CheckStyle",
    "Concurrency",
    "ConcurrencyBehavior",
    "ConcurrencyLimit",
    "Condition",
    "ConversionServiceProvider",
    "ConvertibleMultiValuesString",
    "ConvertibleValuesListString",
    "CreateApiTokenRequest",
    "CreateApiTokenResponse",
    "CreateNamespaceFileRequest",
    "CreateSecurityIntegrationRequest",
    "CrudEventType",
    "DailyExecutionStatistics",
    "DailyExecutionStatisticsDuration",
    "DailyExecutionStatisticsExecutionCounts",
    "Dashboard",
    "DashboardControllerPreviewRequest",
    "DeleteTriggersByQueryRequest",
    "DeletedInterface",
    "DependsOn",
    "DocumentationWithSchema",
    "EditionProviderEdition",
    "Email",
    "EventAppResponse",
    "EventExecution",
    "EventExecutionStatusEvent",
    "EventLogEntry",
    "ExecutableTaskSubflowId",
    "Execution",
    "ExecutionControllerApiValidateExecutionInputsResponse",
    "ExecutionControllerApiValidateExecutionInputsResponseApiCheckFailure",
    "ExecutionControllerApiValidateExecutionInputsResponseApiInputAndValue",
    "ExecutionControllerApiValidateExecutionInputsResponseApiInputError",
    "ExecutionControllerEvalResult",
    "ExecutionControllerExecutionResponse",
    "ExecutionControllerLastExecutionResponse",
    "ExecutionControllerSetLabelsByIdsRequest",
    "ExecutionControllerStateRequest",
    "ExecutionControllerWebhookResponse",
    "ExecutionKind",
    "ExecutionMetadata",
    "ExecutionRepositoryInterfaceChildFilter",
    "ExecutionRepositoryInterfaceFlowFilter",
    "ExecutionStatusEvent",
    "ExecutionTrigger",
    "ExecutionUsage",
    "FileAttributes",
    "FileAttributesFileType",
    "FileMetas",
    "Filter",
    "Fixtures",
    "Flow",
    "FlowControllerTaskValidationType",
    "FlowForExecution",
    "FlowGenerationPrompt",
    "FlowGraph",
    "FlowGraphCluster",
    "FlowGraphEdge",
    "FlowId",
    "FlowInterface",
    "FlowNode",
    "FlowRelation",
    "FlowScope",
    "FlowTopologyGraph",
    "FlowTopologyGraphEdge",
    "FlowUsage",
    "FlowWithSource",
    "GroupIdentifier",
    "GroupIdentifierMembership",
    "GroupUsage",
    "HttpParameters",
    "IAMBindingControllerApiBindingDetail",
    "IAMBindingControllerApiBindingGroup",
    "IAMBindingControllerApiBindingUser",
    "IAMBindingControllerApiCreateBindingRequest",
    "IAMBindingControllerApiRole",
    "IAMGroupControllerApiCreateGroupRequest",
    "IAMGroupControllerApiGroupDetail",
    "IAMGroupControllerApiGroupMember",
    "IAMGroupControllerApiGroupMembership",
    "IAMGroupControllerApiUpdateGroupRequest",
    "IAMInvitationControllerApiInvitationCreateRequest",
    "IAMInvitationControllerApiInvitationDetail",
    "IAMInvitationControllerApiInvitationRole",
    "IAMRoleControllerApiRoleCreateOrUpdateRequest",
    "IAMRoleControllerApiRoleCreateOrUpdateRequestPermissions",
    "IAMRoleControllerApiRoleDetail",
    "IAMServiceAccountControllerApiCreateServiceAccountRequest",
    "IAMServiceAccountControllerApiGroup",
    "IAMServiceAccountControllerApiPatchServiceAccountRequest",
    "IAMServiceAccountControllerApiServiceAccountDetail",
    "IAMServiceAccountControllerApiServiceAccountRequest",
    "IAMServiceAccountControllerApiServiceAccountResponse",
    "IAMTenantAccessControllerApiAuthentication",
    "IAMTenantAccessControllerApiCreateTenantAccessRequest",
    "IAMTenantAccessControllerApiGroup",
    "IAMTenantAccessControllerApiRoleAssignment",
    "IAMTenantAccessControllerApiTenantAccess",
    "IAMTenantAccessControllerApiUserPermission",
    "IAMTenantAccessControllerApiUserTenantAccess",
    "IAMTenantAccessControllerUserApiAutocomplete",
    "IAMUserControllerApiCreateOrUpdateUserRequest",
    "IAMUserControllerApiGroup",
    "IAMUserControllerApiPatchRestrictedRequest",
    "IAMUserControllerApiPatchUserPasswordRequest",
    "IAMUserControllerApiUser",
    "IAMUserControllerApiUserAuth",
    "IAMUserControllerApiUserSummary",
    "IAMUserGroupControllerApiUpdateUserGroupsRequest",
    "IdWithNamespace",
    "IdentityProvider",
    "InputObject",
    "InputType",
    "InstanceControllerApiActiveService",
    "InstanceControllerApiActiveServiceList",
    "InstanceControllerApiCreateOrUpdateWorkerGroupRequest",
    "InstanceControllerApiPluginArtifact",
    "InstanceControllerApiPluginArtifactListPluginArtifact",
    "InstanceControllerApiPluginArtifactListPluginResolutionResult",
    "InstanceControllerApiPluginListRequest",
    "InstanceControllerApiPluginVersionDetails",
    "InstanceControllerApiPluginVersionDetailsApiPluginClass",
    "InstanceControllerApiPluginVersionDetailsApiPluginClasses",
    "InstanceControllerApiPluginVersions",
    "InstanceControllerApiPluginVersionsApiPluginVersionAndMetadata",
    "InstanceControllerApiServerInstance",
    "InstanceControllerApiServiceInstance",
    "InstanceControllerApiWorkerGroup",
    "InstanceControllerApiWorkerGroupDetails",
    "InstanceControllerApiWorkerGroupItem",
    "InstanceControllerApiWorkerGroupList",
    "Invitation",
    "InvitationInvitationStatus",
    "Isolation",
    "KVControllerApiDeleteBulkRequest",
    "KVControllerApiDeleteBulkResponse",
    "KVControllerTypedValue",
    "KVEntry",
    "KVType",
    "Label",
    "LeftSidebarConfiguration",
    "Level",
    "Listener",
    "LogEntry",
    "MapObjectObject",
    "MeControllerApiMe",
    "MeControllerApiProfile",
    "MeControllerApiTenant",
    "MeControllerApiUpdatePasswordRequest",
    "MeControllerApiUserDetailsRequest",
    "Meta",
    "Metric",
    "MetricAggregation",
    "MetricAggregations",
    "MetricEntry",
    "MetricTag",
    "MiscControllerApiUsage",
    "MiscControllerConfiguration",
    "MiscControllerEEConfiguration",
    "MiscControllerEnvironment",
    "MiscControllerLicenseInfo",
    "MiscControllerPluginIdAndVersion",
    "MiscControllerPreview",
    "MiscControllerTenantConfigurationInfo",
    "ModelSchema",
    "Name",
    "Namespace",
    "NamespaceAllowedNamespace",
    "NamespaceAllowedTrigger",
    "NamespaceFileRevision",
    "NamespaceLight",
    "Output",
    "OutputValue",
    "PageRequest",
    "PagedResultsApiGroupSummary",
    "PagedResultsApiRoleSummary",
    "PagedResultsAppsControllerApiApp",
    "PagedResultsAppsControllerApiAppCatalogItem",
    "PagedResultsAssetsControllerApiAsset",
    "PagedResultsAssetsControllerApiAssetUsage",
    "PagedResultsAuditLogControllerApiAuditLogItem",
    "PagedResultsBlueprint",
    "PagedResultsBlueprintControllerApiBlueprintItem",
    "PagedResultsConcurrencyLimit",
    "PagedResultsDashboard",
    "PagedResultsExecution",
    "PagedResultsFlow",
    "PagedResultsIAMBindingControllerApiBindingDetail",
    "PagedResultsIAMGroupControllerApiGroupMember",
    "PagedResultsIAMInvitationControllerApiInvitationDetail",
    "PagedResultsIAMServiceAccountControllerApiServiceAccountDetail",
    "PagedResultsIAMTenantAccessControllerApiUserTenantAccess",
    "PagedResultsIAMUserControllerApiUserSummary",
    "PagedResultsInstanceControllerApiPluginArtifact",
    "PagedResultsInstanceControllerApiServiceInstance",
    "PagedResultsKVEntry",
    "PagedResultsLogEntry",
    "PagedResultsMapStringObject",
    "PagedResultsMetricEntry",
    "PagedResultsNamespace",
    "PagedResultsSearchResultFlow",
    "PagedResultsTenant",
    "PagedResultsTestSuite",
    "PagedResultsTestSuiteRunResult",
    "PagedResultsTrigger",
    "PagedResultsTriggerControllerTriggers",
    "PatchOperation",
    "PatchOperationPath",
    "PatchOperationType",
    "PatchRequest",
    "Permission",
    "Plugin",
    "PluginArtifact",
    "PluginArtifactMetadata",
    "PluginControllerApiPluginVersions",
    "PluginDefault",
    "PluginIcon",
    "PluginPluginElementMetadata",
    "PluginSchema",
    "PluginSubGroupPluginCategory",
    "PropertyAssetsDeclaration",
    "PropertyBoolean",
    "PropertyDouble",
    "PropertyDuration",
    "PropertyListString",
    "PropertyObject",
    "PropertyString",
    "QueryFilter",
    "QueryFilterField",
    "QueryFilterOp",
    "RBACServiceRoleAssignmentRoleOrigin",
    "Relation",
    "Relation1",
    "RelationType",
    "ResourceType",
    "ResourceType1",
    "ResourceTypeSchemaExtensionConfiguration",
    "RightSidebarConfiguration",
    "RightSidebarConfigurationCustomLink",
    "Role",
    "RoleUsage",
    "SLA",
    "SLABehavior",
    "SLALabels",
    "SLAType",
    "SchemaAttribute",
    "SchemaAttributeMutability",
    "SchemaAttributeReturned",
    "SchemaAttributeType",
    "SchemaAttributeUniqueness",
    "SchemaType",
    "ScimExtension",
    "ScimResource",
    "ScimResourceWithOptionalId",
    "ScimUser",
    "SearchRequest",
    "SearchResultFlow",
    "SecurityIntegrationType",
    "ServerConfig",
    "ServerConfigLiveness",
    "ServerInstance",
    "ServerInstanceType",
    "ServiceInstance",
    "ServiceInstanceTimestampedEvent",
    "ServiceProviderConfiguration",
    "ServiceProviderConfigurationAuthenticationSchema",
    "ServiceProviderConfigurationAuthenticationSchemaType",
    "ServiceProviderConfigurationBulkConfiguration",
    "ServiceProviderConfigurationFilterConfiguration",
    "ServiceProviderConfigurationSupportedConfiguration",
    "ServiceServiceState",
    "ServiceType",
    "SetAppsCatalogLogoRequest",
    "SetupConfiguration",
    "SetupConfigurationSetupData",
    "SortOrder",
    "SortRequest",
    "State",
    "StateHistory",
    "StateType",
    "Task",
    "TaskFixture",
    "TaskForExecution",
    "TaskRun",
    "TaskRunAttempt",
    "Tenant",
    "TenantAppCatalogConfig",
    "TenantControllerAppsCatalogConfigRequest",
    "TenantControllerAppsCatalogConfigResponse",
    "TenantInterface",
    "TenantUsage",
    "TestState",
    "TestSuite",
    "TestSuiteControllerRunRequest",
    "TestSuiteControllerSearchTestsLastResult",
    "TestSuiteControllerTestSuiteApiId",
    "TestSuiteControllerTestSuiteBulkRequest",
    "TestSuiteControllerTestsLastResultResponse",
    "TestSuiteRunResult",
    "TestSuiteServiceRunByQueryRequest",
    "TestSuiteServiceTestRunByQueryResult",
    "TheLabelsToPassToTheExecutionCreated",
    "TimeWindow",
    "Trigger",
    "TriggerContext",
    "TriggerControllerSetDisabledRequest",
    "TriggerControllerTriggers",
    "TriggerFixture",
    "Type",
    "UnitTest",
    "UnitTestResult",
    "UploadVersionedPluginsRequest",
    "UsageEE",
    "UserGroup",
    "UserGroupType",
    "UserType",
    "UserUsage",
    "UsernamePasswordCredentials",
    "ValidateConstraintViolation",
    "ValuePathExpression",
    "WorkerGroup",
    "WorkerGroupFallback",
    "WorkerTaskRestartStrategy",
]

# import apis into sdk package
from kestrapy.api.executions_api import ExecutionsApi as ExecutionsApi
from kestrapy.api.flows_api import FlowsApi as FlowsApi
from kestrapy.api.groups_api import GroupsApi as GroupsApi
from kestrapy.api.kv_api import KVApi as KVApi
from kestrapy.api.namespaces_api import NamespacesApi as NamespacesApi
from kestrapy.api.roles_api import RolesApi as RolesApi
from kestrapy.api.service_account_api import ServiceAccountApi as ServiceAccountApi
from kestrapy.api.triggers_api import TriggersApi as TriggersApi
from kestrapy.api.users_api import UsersApi as UsersApi

# import ApiClient
from kestrapy.api_response import ApiResponse as ApiResponse
from kestrapy.api_client import ApiClient as ApiClient
from kestrapy.configuration import Configuration as Configuration
from kestrapy.exceptions import OpenApiException as OpenApiException
from kestrapy.exceptions import ApiTypeError as ApiTypeError
from kestrapy.exceptions import ApiValueError as ApiValueError
from kestrapy.exceptions import ApiKeyError as ApiKeyError
from kestrapy.exceptions import ApiAttributeError as ApiAttributeError
from kestrapy.exceptions import ApiException as ApiException

# import models into sdk package
from kestrapy.models.abstract_flow import AbstractFlow as AbstractFlow
from kestrapy.models.abstract_graph import AbstractGraph as AbstractGraph
from kestrapy.models.abstract_graph_branch_type import AbstractGraphBranchType as AbstractGraphBranchType
from kestrapy.models.abstract_metric_entry_object import AbstractMetricEntryObject as AbstractMetricEntryObject
from kestrapy.models.abstract_trigger import AbstractTrigger as AbstractTrigger
from kestrapy.models.abstract_trigger_for_execution import AbstractTriggerForExecution as AbstractTriggerForExecution
from kestrapy.models.abstract_user import AbstractUser as AbstractUser
from kestrapy.models.abstract_user_tenant_identity_provider import AbstractUserTenantIdentityProvider as AbstractUserTenantIdentityProvider
from kestrapy.models.action import Action as Action
from kestrapy.models.api_auth import ApiAuth as ApiAuth
from kestrapy.models.api_autocomplete import ApiAutocomplete as ApiAutocomplete
from kestrapy.models.api_group_summary import ApiGroupSummary as ApiGroupSummary
from kestrapy.models.api_ids import ApiIds as ApiIds
from kestrapy.models.api_patch_super_admin_request import ApiPatchSuperAdminRequest as ApiPatchSuperAdminRequest
from kestrapy.models.api_role_summary import ApiRoleSummary as ApiRoleSummary
from kestrapy.models.api_secret_list_response_api_secret_meta import ApiSecretListResponseApiSecretMeta as ApiSecretListResponseApiSecretMeta
from kestrapy.models.api_secret_meta import ApiSecretMeta as ApiSecretMeta
from kestrapy.models.api_secret_meta_ee import ApiSecretMetaEE as ApiSecretMetaEE
from kestrapy.models.api_secret_tag import ApiSecretTag as ApiSecretTag
from kestrapy.models.api_secret_value import ApiSecretValue as ApiSecretValue
from kestrapy.models.api_tenant import ApiTenant as ApiTenant
from kestrapy.models.api_tenant_summary import ApiTenantSummary as ApiTenantSummary
from kestrapy.models.api_token import ApiToken as ApiToken
from kestrapy.models.api_token_list import ApiTokenList as ApiTokenList
from kestrapy.models.api_user import ApiUser as ApiUser
from kestrapy.models.app_response import AppResponse as AppResponse
from kestrapy.models.app_response_ui_layout import AppResponseUILayout as AppResponseUILayout
from kestrapy.models.apps_controller_api_app import AppsControllerApiApp as AppsControllerApiApp
from kestrapy.models.apps_controller_api_app_catalog_item import AppsControllerApiAppCatalogItem as AppsControllerApiAppCatalogItem
from kestrapy.models.apps_controller_api_app_source import AppsControllerApiAppSource as AppsControllerApiAppSource
from kestrapy.models.apps_controller_api_app_tags import AppsControllerApiAppTags as AppsControllerApiAppTags
from kestrapy.models.apps_controller_api_bulk_import_response import AppsControllerApiBulkImportResponse as AppsControllerApiBulkImportResponse
from kestrapy.models.apps_controller_api_bulk_import_response_error import AppsControllerApiBulkImportResponseError as AppsControllerApiBulkImportResponseError
from kestrapy.models.apps_controller_api_bulk_operation_request import AppsControllerApiBulkOperationRequest as AppsControllerApiBulkOperationRequest
from kestrapy.models.assertion import Assertion as Assertion
from kestrapy.models.assertion_result import AssertionResult as AssertionResult
from kestrapy.models.assertion_run_error import AssertionRunError as AssertionRunError
from kestrapy.models.asset import Asset as Asset
from kestrapy.models.asset_identifier import AssetIdentifier as AssetIdentifier
from kestrapy.models.asset_topology_graph import AssetTopologyGraph as AssetTopologyGraph
from kestrapy.models.asset_topology_graph_edge import AssetTopologyGraphEdge as AssetTopologyGraphEdge
from kestrapy.models.asset_topology_graph_node import AssetTopologyGraphNode as AssetTopologyGraphNode
from kestrapy.models.asset_topology_graph_node_node_type import AssetTopologyGraphNodeNodeType as AssetTopologyGraphNodeNodeType
from kestrapy.models.assets_controller_api_asset import AssetsControllerApiAsset as AssetsControllerApiAsset
from kestrapy.models.assets_controller_api_asset_usage import AssetsControllerApiAssetUsage as AssetsControllerApiAssetUsage
from kestrapy.models.assets_declaration import AssetsDeclaration as AssetsDeclaration
from kestrapy.models.assets_in_out import AssetsInOut as AssetsInOut
from kestrapy.models.attribute_reference import AttributeReference as AttributeReference
from kestrapy.models.audit_log import AuditLog as AuditLog
from kestrapy.models.audit_log_controller_api_audit_log_item import AuditLogControllerApiAuditLogItem as AuditLogControllerApiAuditLogItem
from kestrapy.models.audit_log_controller_audit_log_diff import AuditLogControllerAuditLogDiff as AuditLogControllerAuditLogDiff
from kestrapy.models.audit_log_controller_audit_log_option import AuditLogControllerAuditLogOption as AuditLogControllerAuditLogOption
from kestrapy.models.audit_log_controller_find_request import AuditLogControllerFindRequest as AuditLogControllerFindRequest
from kestrapy.models.audit_log_detail import AuditLogDetail as AuditLogDetail
from kestrapy.models.auth_controller_auth import AuthControllerAuth as AuthControllerAuth
from kestrapy.models.auth_controller_invitation_user_request import AuthControllerInvitationUserRequest as AuthControllerInvitationUserRequest
from kestrapy.models.auth_controller_reset_password_request import AuthControllerResetPasswordRequest as AuthControllerResetPasswordRequest
from kestrapy.models.backfill import Backfill as Backfill
from kestrapy.models.banner import Banner as Banner
from kestrapy.models.banner_type import BannerType as BannerType
from kestrapy.models.base_audit_log import BaseAuditLog as BaseAuditLog
from kestrapy.models.base_resource_patch_request import BaseResourcePatchRequest as BaseResourcePatchRequest
from kestrapy.models.base_resource_scim_resource import BaseResourceScimResource as BaseResourceScimResource
from kestrapy.models.base_resource_search_request import BaseResourceSearchRequest as BaseResourceSearchRequest
from kestrapy.models.basic_auth_credentials import BasicAuthCredentials as BasicAuthCredentials
from kestrapy.models.binding import Binding as Binding
from kestrapy.models.binding_type import BindingType as BindingType
from kestrapy.models.blueprint import Blueprint as Blueprint
from kestrapy.models.blueprint_controller_api_blueprint_item import BlueprintControllerApiBlueprintItem as BlueprintControllerApiBlueprintItem
from kestrapy.models.blueprint_controller_api_blueprint_item_with_source import BlueprintControllerApiBlueprintItemWithSource as BlueprintControllerApiBlueprintItemWithSource
from kestrapy.models.blueprint_controller_api_blueprint_tag_item import BlueprintControllerApiBlueprintTagItem as BlueprintControllerApiBlueprintTagItem
from kestrapy.models.blueprint_controller_api_flow_blueprint import BlueprintControllerApiFlowBlueprint as BlueprintControllerApiFlowBlueprint
from kestrapy.models.blueprint_controller_flow_blueprint_create_or_update import BlueprintControllerFlowBlueprintCreateOrUpdate as BlueprintControllerFlowBlueprintCreateOrUpdate
from kestrapy.models.blueprint_controller_kind import BlueprintControllerKind as BlueprintControllerKind
from kestrapy.models.blueprint_controller_use_blueprint_template_request import BlueprintControllerUseBlueprintTemplateRequest as BlueprintControllerUseBlueprintTemplateRequest
from kestrapy.models.blueprint_controller_use_blueprint_template_response import BlueprintControllerUseBlueprintTemplateResponse as BlueprintControllerUseBlueprintTemplateResponse
from kestrapy.models.blueprint_template import BlueprintTemplate as BlueprintTemplate
from kestrapy.models.blueprint_with_flow_entity import BlueprintWithFlowEntity as BlueprintWithFlowEntity
from kestrapy.models.breakpoint import Breakpoint as Breakpoint
from kestrapy.models.bulk_error_response import BulkErrorResponse as BulkErrorResponse
from kestrapy.models.bulk_import_apps_request import BulkImportAppsRequest as BulkImportAppsRequest
from kestrapy.models.bulk_response import BulkResponse as BulkResponse
from kestrapy.models.cache import Cache as Cache
from kestrapy.models.chart_chart_option import ChartChartOption as ChartChartOption
from kestrapy.models.chart_filters_overrides import ChartFiltersOverrides as ChartFiltersOverrides
from kestrapy.models.check import Check as Check
from kestrapy.models.check_behavior import CheckBehavior as CheckBehavior
from kestrapy.models.check_style import CheckStyle as CheckStyle
from kestrapy.models.concurrency import Concurrency as Concurrency
from kestrapy.models.concurrency_behavior import ConcurrencyBehavior as ConcurrencyBehavior
from kestrapy.models.concurrency_limit import ConcurrencyLimit as ConcurrencyLimit
from kestrapy.models.condition import Condition as Condition
from kestrapy.models.conversion_service_provider import ConversionServiceProvider as ConversionServiceProvider
from kestrapy.models.convertible_multi_values_string import ConvertibleMultiValuesString as ConvertibleMultiValuesString
from kestrapy.models.convertible_values_list_string import ConvertibleValuesListString as ConvertibleValuesListString
from kestrapy.models.create_api_token_request import CreateApiTokenRequest as CreateApiTokenRequest
from kestrapy.models.create_api_token_response import CreateApiTokenResponse as CreateApiTokenResponse
from kestrapy.models.create_namespace_file_request import CreateNamespaceFileRequest as CreateNamespaceFileRequest
from kestrapy.models.create_security_integration_request import CreateSecurityIntegrationRequest as CreateSecurityIntegrationRequest
from kestrapy.models.crud_event_type import CrudEventType as CrudEventType
from kestrapy.models.daily_execution_statistics import DailyExecutionStatistics as DailyExecutionStatistics
from kestrapy.models.daily_execution_statistics_duration import DailyExecutionStatisticsDuration as DailyExecutionStatisticsDuration
from kestrapy.models.daily_execution_statistics_execution_counts import DailyExecutionStatisticsExecutionCounts as DailyExecutionStatisticsExecutionCounts
from kestrapy.models.dashboard import Dashboard as Dashboard
from kestrapy.models.dashboard_controller_preview_request import DashboardControllerPreviewRequest as DashboardControllerPreviewRequest
from kestrapy.models.delete_triggers_by_query_request import DeleteTriggersByQueryRequest as DeleteTriggersByQueryRequest
from kestrapy.models.deleted_interface import DeletedInterface as DeletedInterface
from kestrapy.models.depends_on import DependsOn as DependsOn
from kestrapy.models.documentation_with_schema import DocumentationWithSchema as DocumentationWithSchema
from kestrapy.models.edition_provider_edition import EditionProviderEdition as EditionProviderEdition
from kestrapy.models.email import Email as Email
from kestrapy.models.event_app_response import EventAppResponse as EventAppResponse
from kestrapy.models.event_execution import EventExecution as EventExecution
from kestrapy.models.event_execution_status_event import EventExecutionStatusEvent as EventExecutionStatusEvent
from kestrapy.models.event_log_entry import EventLogEntry as EventLogEntry
from kestrapy.models.executable_task_subflow_id import ExecutableTaskSubflowId as ExecutableTaskSubflowId
from kestrapy.models.execution import Execution as Execution
from kestrapy.models.execution_controller_api_validate_execution_inputs_response import ExecutionControllerApiValidateExecutionInputsResponse as ExecutionControllerApiValidateExecutionInputsResponse
from kestrapy.models.execution_controller_api_validate_execution_inputs_response_api_check_failure import ExecutionControllerApiValidateExecutionInputsResponseApiCheckFailure as ExecutionControllerApiValidateExecutionInputsResponseApiCheckFailure
from kestrapy.models.execution_controller_api_validate_execution_inputs_response_api_input_and_value import ExecutionControllerApiValidateExecutionInputsResponseApiInputAndValue as ExecutionControllerApiValidateExecutionInputsResponseApiInputAndValue
from kestrapy.models.execution_controller_api_validate_execution_inputs_response_api_input_error import ExecutionControllerApiValidateExecutionInputsResponseApiInputError as ExecutionControllerApiValidateExecutionInputsResponseApiInputError
from kestrapy.models.execution_controller_eval_result import ExecutionControllerEvalResult as ExecutionControllerEvalResult
from kestrapy.models.execution_controller_execution_response import ExecutionControllerExecutionResponse as ExecutionControllerExecutionResponse
from kestrapy.models.execution_controller_last_execution_response import ExecutionControllerLastExecutionResponse as ExecutionControllerLastExecutionResponse
from kestrapy.models.execution_controller_set_labels_by_ids_request import ExecutionControllerSetLabelsByIdsRequest as ExecutionControllerSetLabelsByIdsRequest
from kestrapy.models.execution_controller_state_request import ExecutionControllerStateRequest as ExecutionControllerStateRequest
from kestrapy.models.execution_controller_webhook_response import ExecutionControllerWebhookResponse as ExecutionControllerWebhookResponse
from kestrapy.models.execution_kind import ExecutionKind as ExecutionKind
from kestrapy.models.execution_metadata import ExecutionMetadata as ExecutionMetadata
from kestrapy.models.execution_repository_interface_child_filter import ExecutionRepositoryInterfaceChildFilter as ExecutionRepositoryInterfaceChildFilter
from kestrapy.models.execution_repository_interface_flow_filter import ExecutionRepositoryInterfaceFlowFilter as ExecutionRepositoryInterfaceFlowFilter
from kestrapy.models.execution_status_event import ExecutionStatusEvent as ExecutionStatusEvent
from kestrapy.models.execution_trigger import ExecutionTrigger as ExecutionTrigger
from kestrapy.models.execution_usage import ExecutionUsage as ExecutionUsage
from kestrapy.models.file_attributes import FileAttributes as FileAttributes
from kestrapy.models.file_attributes_file_type import FileAttributesFileType as FileAttributesFileType
from kestrapy.models.file_metas import FileMetas as FileMetas
from kestrapy.models.filter import Filter as Filter
from kestrapy.models.fixtures import Fixtures as Fixtures
from kestrapy.models.flow import Flow as Flow
from kestrapy.models.flow_controller_task_validation_type import FlowControllerTaskValidationType as FlowControllerTaskValidationType
from kestrapy.models.flow_for_execution import FlowForExecution as FlowForExecution
from kestrapy.models.flow_generation_prompt import FlowGenerationPrompt as FlowGenerationPrompt
from kestrapy.models.flow_graph import FlowGraph as FlowGraph
from kestrapy.models.flow_graph_cluster import FlowGraphCluster as FlowGraphCluster
from kestrapy.models.flow_graph_edge import FlowGraphEdge as FlowGraphEdge
from kestrapy.models.flow_id import FlowId as FlowId
from kestrapy.models.flow_interface import FlowInterface as FlowInterface
from kestrapy.models.flow_node import FlowNode as FlowNode
from kestrapy.models.flow_relation import FlowRelation as FlowRelation
from kestrapy.models.flow_scope import FlowScope as FlowScope
from kestrapy.models.flow_topology_graph import FlowTopologyGraph as FlowTopologyGraph
from kestrapy.models.flow_topology_graph_edge import FlowTopologyGraphEdge as FlowTopologyGraphEdge
from kestrapy.models.flow_usage import FlowUsage as FlowUsage
from kestrapy.models.flow_with_source import FlowWithSource as FlowWithSource
from kestrapy.models.group_identifier import GroupIdentifier as GroupIdentifier
from kestrapy.models.group_identifier_membership import GroupIdentifierMembership as GroupIdentifierMembership
from kestrapy.models.group_usage import GroupUsage as GroupUsage
from kestrapy.models.http_parameters import HttpParameters as HttpParameters
from kestrapy.models.iam_binding_controller_api_binding_detail import IAMBindingControllerApiBindingDetail as IAMBindingControllerApiBindingDetail
from kestrapy.models.iam_binding_controller_api_binding_group import IAMBindingControllerApiBindingGroup as IAMBindingControllerApiBindingGroup
from kestrapy.models.iam_binding_controller_api_binding_user import IAMBindingControllerApiBindingUser as IAMBindingControllerApiBindingUser
from kestrapy.models.iam_binding_controller_api_create_binding_request import IAMBindingControllerApiCreateBindingRequest as IAMBindingControllerApiCreateBindingRequest
from kestrapy.models.iam_binding_controller_api_role import IAMBindingControllerApiRole as IAMBindingControllerApiRole
from kestrapy.models.iam_group_controller_api_create_group_request import IAMGroupControllerApiCreateGroupRequest as IAMGroupControllerApiCreateGroupRequest
from kestrapy.models.iam_group_controller_api_group_detail import IAMGroupControllerApiGroupDetail as IAMGroupControllerApiGroupDetail
from kestrapy.models.iam_group_controller_api_group_member import IAMGroupControllerApiGroupMember as IAMGroupControllerApiGroupMember
from kestrapy.models.iam_group_controller_api_group_membership import IAMGroupControllerApiGroupMembership as IAMGroupControllerApiGroupMembership
from kestrapy.models.iam_group_controller_api_update_group_request import IAMGroupControllerApiUpdateGroupRequest as IAMGroupControllerApiUpdateGroupRequest
from kestrapy.models.iam_invitation_controller_api_invitation_create_request import IAMInvitationControllerApiInvitationCreateRequest as IAMInvitationControllerApiInvitationCreateRequest
from kestrapy.models.iam_invitation_controller_api_invitation_detail import IAMInvitationControllerApiInvitationDetail as IAMInvitationControllerApiInvitationDetail
from kestrapy.models.iam_invitation_controller_api_invitation_role import IAMInvitationControllerApiInvitationRole as IAMInvitationControllerApiInvitationRole
from kestrapy.models.iam_role_controller_api_role_create_or_update_request import IAMRoleControllerApiRoleCreateOrUpdateRequest as IAMRoleControllerApiRoleCreateOrUpdateRequest
from kestrapy.models.iam_role_controller_api_role_create_or_update_request_permissions import IAMRoleControllerApiRoleCreateOrUpdateRequestPermissions as IAMRoleControllerApiRoleCreateOrUpdateRequestPermissions
from kestrapy.models.iam_role_controller_api_role_detail import IAMRoleControllerApiRoleDetail as IAMRoleControllerApiRoleDetail
from kestrapy.models.iam_service_account_controller_api_create_service_account_request import IAMServiceAccountControllerApiCreateServiceAccountRequest as IAMServiceAccountControllerApiCreateServiceAccountRequest
from kestrapy.models.iam_service_account_controller_api_group import IAMServiceAccountControllerApiGroup as IAMServiceAccountControllerApiGroup
from kestrapy.models.iam_service_account_controller_api_patch_service_account_request import IAMServiceAccountControllerApiPatchServiceAccountRequest as IAMServiceAccountControllerApiPatchServiceAccountRequest
from kestrapy.models.iam_service_account_controller_api_service_account_detail import IAMServiceAccountControllerApiServiceAccountDetail as IAMServiceAccountControllerApiServiceAccountDetail
from kestrapy.models.iam_service_account_controller_api_service_account_request import IAMServiceAccountControllerApiServiceAccountRequest as IAMServiceAccountControllerApiServiceAccountRequest
from kestrapy.models.iam_service_account_controller_api_service_account_response import IAMServiceAccountControllerApiServiceAccountResponse as IAMServiceAccountControllerApiServiceAccountResponse
from kestrapy.models.iam_tenant_access_controller_api_authentication import IAMTenantAccessControllerApiAuthentication as IAMTenantAccessControllerApiAuthentication
from kestrapy.models.iam_tenant_access_controller_api_create_tenant_access_request import IAMTenantAccessControllerApiCreateTenantAccessRequest as IAMTenantAccessControllerApiCreateTenantAccessRequest
from kestrapy.models.iam_tenant_access_controller_api_group import IAMTenantAccessControllerApiGroup as IAMTenantAccessControllerApiGroup
from kestrapy.models.iam_tenant_access_controller_api_role_assignment import IAMTenantAccessControllerApiRoleAssignment as IAMTenantAccessControllerApiRoleAssignment
from kestrapy.models.iam_tenant_access_controller_api_tenant_access import IAMTenantAccessControllerApiTenantAccess as IAMTenantAccessControllerApiTenantAccess
from kestrapy.models.iam_tenant_access_controller_api_user_permission import IAMTenantAccessControllerApiUserPermission as IAMTenantAccessControllerApiUserPermission
from kestrapy.models.iam_tenant_access_controller_api_user_tenant_access import IAMTenantAccessControllerApiUserTenantAccess as IAMTenantAccessControllerApiUserTenantAccess
from kestrapy.models.iam_tenant_access_controller_user_api_autocomplete import IAMTenantAccessControllerUserApiAutocomplete as IAMTenantAccessControllerUserApiAutocomplete
from kestrapy.models.iam_user_controller_api_create_or_update_user_request import IAMUserControllerApiCreateOrUpdateUserRequest as IAMUserControllerApiCreateOrUpdateUserRequest
from kestrapy.models.iam_user_controller_api_group import IAMUserControllerApiGroup as IAMUserControllerApiGroup
from kestrapy.models.iam_user_controller_api_patch_restricted_request import IAMUserControllerApiPatchRestrictedRequest as IAMUserControllerApiPatchRestrictedRequest
from kestrapy.models.iam_user_controller_api_patch_user_password_request import IAMUserControllerApiPatchUserPasswordRequest as IAMUserControllerApiPatchUserPasswordRequest
from kestrapy.models.iam_user_controller_api_user import IAMUserControllerApiUser as IAMUserControllerApiUser
from kestrapy.models.iam_user_controller_api_user_auth import IAMUserControllerApiUserAuth as IAMUserControllerApiUserAuth
from kestrapy.models.iam_user_controller_api_user_summary import IAMUserControllerApiUserSummary as IAMUserControllerApiUserSummary
from kestrapy.models.iam_user_group_controller_api_update_user_groups_request import IAMUserGroupControllerApiUpdateUserGroupsRequest as IAMUserGroupControllerApiUpdateUserGroupsRequest
from kestrapy.models.id_with_namespace import IdWithNamespace as IdWithNamespace
from kestrapy.models.identity_provider import IdentityProvider as IdentityProvider
from kestrapy.models.input_object import InputObject as InputObject
from kestrapy.models.input_type import InputType as InputType
from kestrapy.models.instance_controller_api_active_service import InstanceControllerApiActiveService as InstanceControllerApiActiveService
from kestrapy.models.instance_controller_api_active_service_list import InstanceControllerApiActiveServiceList as InstanceControllerApiActiveServiceList
from kestrapy.models.instance_controller_api_create_or_update_worker_group_request import InstanceControllerApiCreateOrUpdateWorkerGroupRequest as InstanceControllerApiCreateOrUpdateWorkerGroupRequest
from kestrapy.models.instance_controller_api_plugin_artifact import InstanceControllerApiPluginArtifact as InstanceControllerApiPluginArtifact
from kestrapy.models.instance_controller_api_plugin_artifact_list_plugin_artifact import InstanceControllerApiPluginArtifactListPluginArtifact as InstanceControllerApiPluginArtifactListPluginArtifact
from kestrapy.models.instance_controller_api_plugin_artifact_list_plugin_resolution_result import InstanceControllerApiPluginArtifactListPluginResolutionResult as InstanceControllerApiPluginArtifactListPluginResolutionResult
from kestrapy.models.instance_controller_api_plugin_list_request import InstanceControllerApiPluginListRequest as InstanceControllerApiPluginListRequest
from kestrapy.models.instance_controller_api_plugin_version_details import InstanceControllerApiPluginVersionDetails as InstanceControllerApiPluginVersionDetails
from kestrapy.models.instance_controller_api_plugin_version_details_api_plugin_class import InstanceControllerApiPluginVersionDetailsApiPluginClass as InstanceControllerApiPluginVersionDetailsApiPluginClass
from kestrapy.models.instance_controller_api_plugin_version_details_api_plugin_classes import InstanceControllerApiPluginVersionDetailsApiPluginClasses as InstanceControllerApiPluginVersionDetailsApiPluginClasses
from kestrapy.models.instance_controller_api_plugin_versions import InstanceControllerApiPluginVersions as InstanceControllerApiPluginVersions
from kestrapy.models.instance_controller_api_plugin_versions_api_plugin_version_and_metadata import InstanceControllerApiPluginVersionsApiPluginVersionAndMetadata as InstanceControllerApiPluginVersionsApiPluginVersionAndMetadata
from kestrapy.models.instance_controller_api_server_instance import InstanceControllerApiServerInstance as InstanceControllerApiServerInstance
from kestrapy.models.instance_controller_api_service_instance import InstanceControllerApiServiceInstance as InstanceControllerApiServiceInstance
from kestrapy.models.instance_controller_api_worker_group import InstanceControllerApiWorkerGroup as InstanceControllerApiWorkerGroup
from kestrapy.models.instance_controller_api_worker_group_details import InstanceControllerApiWorkerGroupDetails as InstanceControllerApiWorkerGroupDetails
from kestrapy.models.instance_controller_api_worker_group_item import InstanceControllerApiWorkerGroupItem as InstanceControllerApiWorkerGroupItem
from kestrapy.models.instance_controller_api_worker_group_list import InstanceControllerApiWorkerGroupList as InstanceControllerApiWorkerGroupList
from kestrapy.models.invitation import Invitation as Invitation
from kestrapy.models.invitation_invitation_status import InvitationInvitationStatus as InvitationInvitationStatus
from kestrapy.models.isolation import Isolation as Isolation
from kestrapy.models.kv_controller_api_delete_bulk_request import KVControllerApiDeleteBulkRequest as KVControllerApiDeleteBulkRequest
from kestrapy.models.kv_controller_api_delete_bulk_response import KVControllerApiDeleteBulkResponse as KVControllerApiDeleteBulkResponse
from kestrapy.models.kv_controller_typed_value import KVControllerTypedValue as KVControllerTypedValue
from kestrapy.models.kv_entry import KVEntry as KVEntry
from kestrapy.models.kv_type import KVType as KVType
from kestrapy.models.label import Label as Label
from kestrapy.models.left_sidebar_configuration import LeftSidebarConfiguration as LeftSidebarConfiguration
from kestrapy.models.level import Level as Level
from kestrapy.models.listener import Listener as Listener
from kestrapy.models.log_entry import LogEntry as LogEntry
from kestrapy.models.map_object_object import MapObjectObject as MapObjectObject
from kestrapy.models.me_controller_api_me import MeControllerApiMe as MeControllerApiMe
from kestrapy.models.me_controller_api_profile import MeControllerApiProfile as MeControllerApiProfile
from kestrapy.models.me_controller_api_tenant import MeControllerApiTenant as MeControllerApiTenant
from kestrapy.models.me_controller_api_update_password_request import MeControllerApiUpdatePasswordRequest as MeControllerApiUpdatePasswordRequest
from kestrapy.models.me_controller_api_user_details_request import MeControllerApiUserDetailsRequest as MeControllerApiUserDetailsRequest
from kestrapy.models.meta import Meta as Meta
from kestrapy.models.metric import Metric as Metric
from kestrapy.models.metric_aggregation import MetricAggregation as MetricAggregation
from kestrapy.models.metric_aggregations import MetricAggregations as MetricAggregations
from kestrapy.models.metric_entry import MetricEntry as MetricEntry
from kestrapy.models.metric_tag import MetricTag as MetricTag
from kestrapy.models.misc_controller_api_usage import MiscControllerApiUsage as MiscControllerApiUsage
from kestrapy.models.misc_controller_configuration import MiscControllerConfiguration as MiscControllerConfiguration
from kestrapy.models.misc_controller_ee_configuration import MiscControllerEEConfiguration as MiscControllerEEConfiguration
from kestrapy.models.misc_controller_environment import MiscControllerEnvironment as MiscControllerEnvironment
from kestrapy.models.misc_controller_license_info import MiscControllerLicenseInfo as MiscControllerLicenseInfo
from kestrapy.models.misc_controller_plugin_id_and_version import MiscControllerPluginIdAndVersion as MiscControllerPluginIdAndVersion
from kestrapy.models.misc_controller_preview import MiscControllerPreview as MiscControllerPreview
from kestrapy.models.misc_controller_tenant_configuration_info import MiscControllerTenantConfigurationInfo as MiscControllerTenantConfigurationInfo
from kestrapy.models.model_schema import ModelSchema as ModelSchema
from kestrapy.models.name import Name as Name
from kestrapy.models.namespace import Namespace as Namespace
from kestrapy.models.namespace_allowed_namespace import NamespaceAllowedNamespace as NamespaceAllowedNamespace
from kestrapy.models.namespace_allowed_trigger import NamespaceAllowedTrigger as NamespaceAllowedTrigger
from kestrapy.models.namespace_file_revision import NamespaceFileRevision as NamespaceFileRevision
from kestrapy.models.namespace_light import NamespaceLight as NamespaceLight
from kestrapy.models.output import Output as Output
from kestrapy.models.output_value import OutputValue as OutputValue
from kestrapy.models.page_request import PageRequest as PageRequest
from kestrapy.models.paged_results_api_group_summary import PagedResultsApiGroupSummary as PagedResultsApiGroupSummary
from kestrapy.models.paged_results_api_role_summary import PagedResultsApiRoleSummary as PagedResultsApiRoleSummary
from kestrapy.models.paged_results_apps_controller_api_app import PagedResultsAppsControllerApiApp as PagedResultsAppsControllerApiApp
from kestrapy.models.paged_results_apps_controller_api_app_catalog_item import PagedResultsAppsControllerApiAppCatalogItem as PagedResultsAppsControllerApiAppCatalogItem
from kestrapy.models.paged_results_assets_controller_api_asset import PagedResultsAssetsControllerApiAsset as PagedResultsAssetsControllerApiAsset
from kestrapy.models.paged_results_assets_controller_api_asset_usage import PagedResultsAssetsControllerApiAssetUsage as PagedResultsAssetsControllerApiAssetUsage
from kestrapy.models.paged_results_audit_log_controller_api_audit_log_item import PagedResultsAuditLogControllerApiAuditLogItem as PagedResultsAuditLogControllerApiAuditLogItem
from kestrapy.models.paged_results_blueprint import PagedResultsBlueprint as PagedResultsBlueprint
from kestrapy.models.paged_results_blueprint_controller_api_blueprint_item import PagedResultsBlueprintControllerApiBlueprintItem as PagedResultsBlueprintControllerApiBlueprintItem
from kestrapy.models.paged_results_concurrency_limit import PagedResultsConcurrencyLimit as PagedResultsConcurrencyLimit
from kestrapy.models.paged_results_dashboard import PagedResultsDashboard as PagedResultsDashboard
from kestrapy.models.paged_results_execution import PagedResultsExecution as PagedResultsExecution
from kestrapy.models.paged_results_flow import PagedResultsFlow as PagedResultsFlow
from kestrapy.models.paged_results_iam_binding_controller_api_binding_detail import PagedResultsIAMBindingControllerApiBindingDetail as PagedResultsIAMBindingControllerApiBindingDetail
from kestrapy.models.paged_results_iam_group_controller_api_group_member import PagedResultsIAMGroupControllerApiGroupMember as PagedResultsIAMGroupControllerApiGroupMember
from kestrapy.models.paged_results_iam_invitation_controller_api_invitation_detail import PagedResultsIAMInvitationControllerApiInvitationDetail as PagedResultsIAMInvitationControllerApiInvitationDetail
from kestrapy.models.paged_results_iam_service_account_controller_api_service_account_detail import PagedResultsIAMServiceAccountControllerApiServiceAccountDetail as PagedResultsIAMServiceAccountControllerApiServiceAccountDetail
from kestrapy.models.paged_results_iam_tenant_access_controller_api_user_tenant_access import PagedResultsIAMTenantAccessControllerApiUserTenantAccess as PagedResultsIAMTenantAccessControllerApiUserTenantAccess
from kestrapy.models.paged_results_iam_user_controller_api_user_summary import PagedResultsIAMUserControllerApiUserSummary as PagedResultsIAMUserControllerApiUserSummary
from kestrapy.models.paged_results_instance_controller_api_plugin_artifact import PagedResultsInstanceControllerApiPluginArtifact as PagedResultsInstanceControllerApiPluginArtifact
from kestrapy.models.paged_results_instance_controller_api_service_instance import PagedResultsInstanceControllerApiServiceInstance as PagedResultsInstanceControllerApiServiceInstance
from kestrapy.models.paged_results_kv_entry import PagedResultsKVEntry as PagedResultsKVEntry
from kestrapy.models.paged_results_log_entry import PagedResultsLogEntry as PagedResultsLogEntry
from kestrapy.models.paged_results_map_string_object import PagedResultsMapStringObject as PagedResultsMapStringObject
from kestrapy.models.paged_results_metric_entry import PagedResultsMetricEntry as PagedResultsMetricEntry
from kestrapy.models.paged_results_namespace import PagedResultsNamespace as PagedResultsNamespace
from kestrapy.models.paged_results_search_result_flow import PagedResultsSearchResultFlow as PagedResultsSearchResultFlow
from kestrapy.models.paged_results_tenant import PagedResultsTenant as PagedResultsTenant
from kestrapy.models.paged_results_test_suite import PagedResultsTestSuite as PagedResultsTestSuite
from kestrapy.models.paged_results_test_suite_run_result import PagedResultsTestSuiteRunResult as PagedResultsTestSuiteRunResult
from kestrapy.models.paged_results_trigger import PagedResultsTrigger as PagedResultsTrigger
from kestrapy.models.paged_results_trigger_controller_triggers import PagedResultsTriggerControllerTriggers as PagedResultsTriggerControllerTriggers
from kestrapy.models.patch_operation import PatchOperation as PatchOperation
from kestrapy.models.patch_operation_path import PatchOperationPath as PatchOperationPath
from kestrapy.models.patch_operation_type import PatchOperationType as PatchOperationType
from kestrapy.models.patch_request import PatchRequest as PatchRequest
from kestrapy.models.permission import Permission as Permission
from kestrapy.models.plugin import Plugin as Plugin
from kestrapy.models.plugin_artifact import PluginArtifact as PluginArtifact
from kestrapy.models.plugin_artifact_metadata import PluginArtifactMetadata as PluginArtifactMetadata
from kestrapy.models.plugin_controller_api_plugin_versions import PluginControllerApiPluginVersions as PluginControllerApiPluginVersions
from kestrapy.models.plugin_default import PluginDefault as PluginDefault
from kestrapy.models.plugin_icon import PluginIcon as PluginIcon
from kestrapy.models.plugin_plugin_element_metadata import PluginPluginElementMetadata as PluginPluginElementMetadata
from kestrapy.models.plugin_schema import PluginSchema as PluginSchema
from kestrapy.models.plugin_sub_group_plugin_category import PluginSubGroupPluginCategory as PluginSubGroupPluginCategory
from kestrapy.models.property_assets_declaration import PropertyAssetsDeclaration as PropertyAssetsDeclaration
from kestrapy.models.property_boolean import PropertyBoolean as PropertyBoolean
from kestrapy.models.property_double import PropertyDouble as PropertyDouble
from kestrapy.models.property_duration import PropertyDuration as PropertyDuration
from kestrapy.models.property_list_string import PropertyListString as PropertyListString
from kestrapy.models.property_object import PropertyObject as PropertyObject
from kestrapy.models.property_string import PropertyString as PropertyString
from kestrapy.models.query_filter import QueryFilter as QueryFilter
from kestrapy.models.query_filter_field import QueryFilterField as QueryFilterField
from kestrapy.models.query_filter_op import QueryFilterOp as QueryFilterOp
from kestrapy.models.rbac_service_role_assignment_role_origin import RBACServiceRoleAssignmentRoleOrigin as RBACServiceRoleAssignmentRoleOrigin
from kestrapy.models.relation import Relation as Relation
from kestrapy.models.relation1 import Relation1 as Relation1
from kestrapy.models.relation_type import RelationType as RelationType
from kestrapy.models.resource_type import ResourceType as ResourceType
from kestrapy.models.resource_type1 import ResourceType1 as ResourceType1
from kestrapy.models.resource_type_schema_extension_configuration import ResourceTypeSchemaExtensionConfiguration as ResourceTypeSchemaExtensionConfiguration
from kestrapy.models.right_sidebar_configuration import RightSidebarConfiguration as RightSidebarConfiguration
from kestrapy.models.right_sidebar_configuration_custom_link import RightSidebarConfigurationCustomLink as RightSidebarConfigurationCustomLink
from kestrapy.models.role import Role as Role
from kestrapy.models.role_usage import RoleUsage as RoleUsage
from kestrapy.models.sla import SLA as SLA
from kestrapy.models.sla_behavior import SLABehavior as SLABehavior
from kestrapy.models.sla_labels import SLALabels as SLALabels
from kestrapy.models.sla_type import SLAType as SLAType
from kestrapy.models.schema_attribute import SchemaAttribute as SchemaAttribute
from kestrapy.models.schema_attribute_mutability import SchemaAttributeMutability as SchemaAttributeMutability
from kestrapy.models.schema_attribute_returned import SchemaAttributeReturned as SchemaAttributeReturned
from kestrapy.models.schema_attribute_type import SchemaAttributeType as SchemaAttributeType
from kestrapy.models.schema_attribute_uniqueness import SchemaAttributeUniqueness as SchemaAttributeUniqueness
from kestrapy.models.schema_type import SchemaType as SchemaType
from kestrapy.models.scim_extension import ScimExtension as ScimExtension
from kestrapy.models.scim_resource import ScimResource as ScimResource
from kestrapy.models.scim_resource_with_optional_id import ScimResourceWithOptionalId as ScimResourceWithOptionalId
from kestrapy.models.scim_user import ScimUser as ScimUser
from kestrapy.models.search_request import SearchRequest as SearchRequest
from kestrapy.models.search_result_flow import SearchResultFlow as SearchResultFlow
from kestrapy.models.security_integration_type import SecurityIntegrationType as SecurityIntegrationType
from kestrapy.models.server_config import ServerConfig as ServerConfig
from kestrapy.models.server_config_liveness import ServerConfigLiveness as ServerConfigLiveness
from kestrapy.models.server_instance import ServerInstance as ServerInstance
from kestrapy.models.server_instance_type import ServerInstanceType as ServerInstanceType
from kestrapy.models.service_instance import ServiceInstance as ServiceInstance
from kestrapy.models.service_instance_timestamped_event import ServiceInstanceTimestampedEvent as ServiceInstanceTimestampedEvent
from kestrapy.models.service_provider_configuration import ServiceProviderConfiguration as ServiceProviderConfiguration
from kestrapy.models.service_provider_configuration_authentication_schema import ServiceProviderConfigurationAuthenticationSchema as ServiceProviderConfigurationAuthenticationSchema
from kestrapy.models.service_provider_configuration_authentication_schema_type import ServiceProviderConfigurationAuthenticationSchemaType as ServiceProviderConfigurationAuthenticationSchemaType
from kestrapy.models.service_provider_configuration_bulk_configuration import ServiceProviderConfigurationBulkConfiguration as ServiceProviderConfigurationBulkConfiguration
from kestrapy.models.service_provider_configuration_filter_configuration import ServiceProviderConfigurationFilterConfiguration as ServiceProviderConfigurationFilterConfiguration
from kestrapy.models.service_provider_configuration_supported_configuration import ServiceProviderConfigurationSupportedConfiguration as ServiceProviderConfigurationSupportedConfiguration
from kestrapy.models.service_service_state import ServiceServiceState as ServiceServiceState
from kestrapy.models.service_type import ServiceType as ServiceType
from kestrapy.models.set_apps_catalog_logo_request import SetAppsCatalogLogoRequest as SetAppsCatalogLogoRequest
from kestrapy.models.setup_configuration import SetupConfiguration as SetupConfiguration
from kestrapy.models.setup_configuration_setup_data import SetupConfigurationSetupData as SetupConfigurationSetupData
from kestrapy.models.sort_order import SortOrder as SortOrder
from kestrapy.models.sort_request import SortRequest as SortRequest
from kestrapy.models.state import State as State
from kestrapy.models.state_history import StateHistory as StateHistory
from kestrapy.models.state_type import StateType as StateType
from kestrapy.models.task import Task as Task
from kestrapy.models.task_fixture import TaskFixture as TaskFixture
from kestrapy.models.task_for_execution import TaskForExecution as TaskForExecution
from kestrapy.models.task_run import TaskRun as TaskRun
from kestrapy.models.task_run_attempt import TaskRunAttempt as TaskRunAttempt
from kestrapy.models.tenant import Tenant as Tenant
from kestrapy.models.tenant_app_catalog_config import TenantAppCatalogConfig as TenantAppCatalogConfig
from kestrapy.models.tenant_controller_apps_catalog_config_request import TenantControllerAppsCatalogConfigRequest as TenantControllerAppsCatalogConfigRequest
from kestrapy.models.tenant_controller_apps_catalog_config_response import TenantControllerAppsCatalogConfigResponse as TenantControllerAppsCatalogConfigResponse
from kestrapy.models.tenant_interface import TenantInterface as TenantInterface
from kestrapy.models.tenant_usage import TenantUsage as TenantUsage
from kestrapy.models.test_state import TestState as TestState
from kestrapy.models.test_suite import TestSuite as TestSuite
from kestrapy.models.test_suite_controller_run_request import TestSuiteControllerRunRequest as TestSuiteControllerRunRequest
from kestrapy.models.test_suite_controller_search_tests_last_result import TestSuiteControllerSearchTestsLastResult as TestSuiteControllerSearchTestsLastResult
from kestrapy.models.test_suite_controller_test_suite_api_id import TestSuiteControllerTestSuiteApiId as TestSuiteControllerTestSuiteApiId
from kestrapy.models.test_suite_controller_test_suite_bulk_request import TestSuiteControllerTestSuiteBulkRequest as TestSuiteControllerTestSuiteBulkRequest
from kestrapy.models.test_suite_controller_tests_last_result_response import TestSuiteControllerTestsLastResultResponse as TestSuiteControllerTestsLastResultResponse
from kestrapy.models.test_suite_run_result import TestSuiteRunResult as TestSuiteRunResult
from kestrapy.models.test_suite_service_run_by_query_request import TestSuiteServiceRunByQueryRequest as TestSuiteServiceRunByQueryRequest
from kestrapy.models.test_suite_service_test_run_by_query_result import TestSuiteServiceTestRunByQueryResult as TestSuiteServiceTestRunByQueryResult
from kestrapy.models.the_labels_to_pass_to_the_execution_created import TheLabelsToPassToTheExecutionCreated as TheLabelsToPassToTheExecutionCreated
from kestrapy.models.time_window import TimeWindow as TimeWindow
from kestrapy.models.trigger import Trigger as Trigger
from kestrapy.models.trigger_context import TriggerContext as TriggerContext
from kestrapy.models.trigger_controller_set_disabled_request import TriggerControllerSetDisabledRequest as TriggerControllerSetDisabledRequest
from kestrapy.models.trigger_controller_triggers import TriggerControllerTriggers as TriggerControllerTriggers
from kestrapy.models.trigger_fixture import TriggerFixture as TriggerFixture
from kestrapy.models.type import Type as Type
from kestrapy.models.unit_test import UnitTest as UnitTest
from kestrapy.models.unit_test_result import UnitTestResult as UnitTestResult
from kestrapy.models.upload_versioned_plugins_request import UploadVersionedPluginsRequest as UploadVersionedPluginsRequest
from kestrapy.models.usage_ee import UsageEE as UsageEE
from kestrapy.models.user_group import UserGroup as UserGroup
from kestrapy.models.user_group_type import UserGroupType as UserGroupType
from kestrapy.models.user_type import UserType as UserType
from kestrapy.models.user_usage import UserUsage as UserUsage
from kestrapy.models.username_password_credentials import UsernamePasswordCredentials as UsernamePasswordCredentials
from kestrapy.models.validate_constraint_violation import ValidateConstraintViolation as ValidateConstraintViolation
from kestrapy.models.value_path_expression import ValuePathExpression as ValuePathExpression
from kestrapy.models.worker_group import WorkerGroup as WorkerGroup
from kestrapy.models.worker_group_fallback import WorkerGroupFallback as WorkerGroupFallback
from kestrapy.models.worker_task_restart_strategy import WorkerTaskRestartStrategy as WorkerTaskRestartStrategy

from kestrapy.kestra_client import KestraClient as KestraClient



# coding: utf-8

"""
    Kestra EE

    All API operations, except for Superadmin-only endpoints, require a tenant identifier in the HTTP path.<br/> Endpoints designated as Superadmin-only are not tenant-scoped.

    The version of the OpenAPI document: 1.1.4
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from kestrapy.api.triggers_api import TriggersApi


class TestTriggersApi(unittest.TestCase):
    """TriggersApi unit test stubs"""

    def setUp(self) -> None:
        self.api = TriggersApi()

    def tearDown(self) -> None:
        pass

    def test_delete_backfill(self) -> None:
        """Test case for delete_backfill

        Delete a backfill
        """
        pass

    def test_delete_backfill_by_ids(self) -> None:
        """Test case for delete_backfill_by_ids

        Delete backfill for given triggers
        """
        pass

    def test_delete_backfill_by_query(self) -> None:
        """Test case for delete_backfill_by_query

        Delete backfill for given triggers
        """
        pass

    def test_disabled_triggers_by_ids(self) -> None:
        """Test case for disabled_triggers_by_ids

        Disable/enable given triggers
        """
        pass

    def test_disabled_triggers_by_query(self) -> None:
        """Test case for disabled_triggers_by_query

        Disable/enable triggers by query parameters
        """
        pass

    def test_pause_backfill(self) -> None:
        """Test case for pause_backfill

        Pause a backfill
        """
        pass

    def test_pause_backfill_by_ids(self) -> None:
        """Test case for pause_backfill_by_ids

        Pause backfill for given triggers
        """
        pass

    def test_pause_backfill_by_query(self) -> None:
        """Test case for pause_backfill_by_query

        Pause backfill for given triggers
        """
        pass

    def test_restart_trigger(self) -> None:
        """Test case for restart_trigger

        Restart a trigger
        """
        pass

    def test_search_triggers(self) -> None:
        """Test case for search_triggers

        Search for triggers
        """
        pass

    def test_search_triggers_for_flow(self) -> None:
        """Test case for search_triggers_for_flow

        Get all triggers for a flow
        """
        pass

    def test_unlock_trigger(self) -> None:
        """Test case for unlock_trigger

        Unlock a trigger
        """
        pass

    def test_unlock_triggers_by_ids(self) -> None:
        """Test case for unlock_triggers_by_ids

        Unlock given triggers
        """
        pass

    def test_unlock_triggers_by_query(self) -> None:
        """Test case for unlock_triggers_by_query

        Unlock triggers by query parameters
        """
        pass

    def test_unpause_backfill(self) -> None:
        """Test case for unpause_backfill

        Unpause a backfill
        """
        pass

    def test_unpause_backfill_by_ids(self) -> None:
        """Test case for unpause_backfill_by_ids

        Unpause backfill for given triggers
        """
        pass

    def test_unpause_backfill_by_query(self) -> None:
        """Test case for unpause_backfill_by_query

        Unpause backfill for given triggers
        """
        pass

    def test_update_trigger(self) -> None:
        """Test case for update_trigger

        Update a trigger
        """
        pass


if __name__ == '__main__':
    unittest.main()
